import sys
from setuptools import setup

setup(
    name="elasticsearch-stubs",
    version="0",
    description="Reserving this package for future use",
    url="https://github.com/elastic/elasticsearch",
    license="Apache-2.0",
    author="Seth Michael Larson",
    author_email="seth.larson@elastic.co"
)
